@@ -193,7 +193,12 @@ def import_schemas(data: dict):
         dataset.dict = data[param['name']]
         result = model_resource.import_data(dataset, dry_run=True)
         if result.has_errors():
-            return {param['name']: result.base_errors}
+            return {
+                param['name']: {
+                    'base_errors': result.base_errors,
+                    'row_errors': result.row_errors()
+                }
+            }
 
         model_resource.import_data(dataset, dry_run=False)
 
